==> openshift-model-console-5.10.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ApplicationMenuSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ApplicationMenuSpecFluentImpl<A extends io.fabric8.openshift.api.model.console.v1.ApplicationMenuSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1.ApplicationMenuSpecFluent<A>{
  public ApplicationMenuSpecFluentImpl() {
  }
  public ApplicationMenuSpecFluentImpl(io.fabric8.openshift.api.model.console.v1.ApplicationMenuSpec instance) {
    this.withImageURL(instance.getImageURL()); 
    this.withSection(instance.getSection()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String imageURL;
  private java.lang.String section;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getImageURL() {
    return this.imageURL;
  }
  public A withImageURL(java.lang.String imageURL) {
    this.imageURL=imageURL; return (A) this;
  }
  public java.lang.Boolean hasImageURL() {
    return this.imageURL != null;
  }
  
  /**
   * Method is deprecated. use withImageURL instead.
   */
  @java.lang.Deprecated
  public A withNewImageURL(java.lang.String arg0) {
    return (A)withImageURL(new String(arg0));
  }
  public java.lang.String getSection() {
    return this.section;
  }
  public A withSection(java.lang.String section) {
    this.section=section; return (A) this;
  }
  public java.lang.Boolean hasSection() {
    return this.section != null;
  }
  
  /**
   * Method is deprecated. use withSection instead.
   */
  @java.lang.Deprecated
  public A withNewSection(java.lang.String arg0) {
    return (A)withSection(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ApplicationMenuSpecFluentImpl that = (ApplicationMenuSpecFluentImpl) o;
    if (imageURL != null ? !imageURL.equals(that.imageURL) :that.imageURL != null) return false;
    if (section != null ? !section.equals(that.section) :that.section != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(imageURL,  section,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-console-5.12.3-sources.jar: io/fabric8/openshift/api/model/console/v1/ApplicationMenuSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ApplicationMenuSpecFluentImpl<A extends io.fabric8.openshift.api.model.console.v1.ApplicationMenuSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1.ApplicationMenuSpecFluent<A>{
  public ApplicationMenuSpecFluentImpl() {
  }
  public ApplicationMenuSpecFluentImpl(io.fabric8.openshift.api.model.console.v1.ApplicationMenuSpec instance) {
    this.withImageURL(instance.getImageURL()); 
    this.withSection(instance.getSection()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String imageURL;
  private java.lang.String section;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getImageURL() {
    return this.imageURL;
  }
  public A withImageURL(java.lang.String imageURL) {
    this.imageURL=imageURL; return (A) this;
  }
  public java.lang.Boolean hasImageURL() {
    return this.imageURL != null;
  }
  
  /**
   * Method is deprecated. use withImageURL instead.
   */
  @java.lang.Deprecated
  public A withNewImageURL(java.lang.String arg0) {
    return (A)withImageURL(new String(arg0));
  }
  public java.lang.String getSection() {
    return this.section;
  }
  public A withSection(java.lang.String section) {
    this.section=section; return (A) this;
  }
  public java.lang.Boolean hasSection() {
    return this.section != null;
  }
  
  /**
   * Method is deprecated. use withSection instead.
   */
  @java.lang.Deprecated
  public A withNewSection(java.lang.String arg0) {
    return (A)withSection(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ApplicationMenuSpecFluentImpl that = (ApplicationMenuSpecFluentImpl) o;
    if (imageURL != null ? !imageURL.equals(that.imageURL) :that.imageURL != null) return false;
    if (section != null ? !section.equals(that.section) :that.section != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(imageURL,  section,  additionalProperties,  super.hashCode());
  }
  
}
